@@ -72,7 +72,9 @@ class PropsDialog(gtk.Dialog):
                      gtk.STOCK_APPLY, gtk.RESPONSE_APPLY)
         )
         self.set_response_sensitive(gtk.RESPONSE_APPLY, False)
-        self.set_size_request(MIN_DIALOG_WIDTH, MIN_DIALOG_HEIGHT)
+        self.set_size_request(*Utils.scale(
+            (MIN_DIALOG_WIDTH, MIN_DIALOG_HEIGHT)
+        ))
         self._block = block
 
         vpaned = gtk.VPaned()
@@ -265,7 +267,7 @@ class PropsDialog(gtk.Dialog):
             insert('\n\n# Variables\n', block.get_var_make())
         insert('\n\n# Blocks\n', block.get_make())
         if src:
-            insert('\n\n# External Code ({}.py)\n'.format(block.get_id()), src)
+            insert('\n\n# External Code ({0}.py)\n'.format(block.get_id()), src)
 
     def _handle_key_press(self, widget, event):
         """
